@@ -1,6 +1,5 @@
 import errno
 import os
-import re
 import tempfile
 import typing
 
@@ -9,9 +8,6 @@ import audeer
 from audbackend.core import utils
 
 
-BACKEND_ALLOWED_CHARS = '[A-Za-z0-9/._-]+'
-
-
 class Backend:
     r"""Abstract backend.
 
@@ -102,6 +98,8 @@ class Backend:
             src_path: str,
             dst_root: str,
             version: str,
+            *,
+            verbose: bool = False,
     ) -> typing.List[str]:
         r"""Get archive from backend and extract.
 
@@ -110,6 +108,7 @@ class Backend:
                 e.g. ``media/archive1``
             dst_root: local destination directory
             version: version string
+            verbose: show debug messages
 
         Returns:
             extracted files
@@ -125,13 +124,23 @@ class Backend:
                 tmp_root,
                 os.path.basename(remote_archive),
             )
-            self.get_file(remote_archive, local_archive, version)
-            return audeer.extract_archive(local_archive, dst_root)
+            self.get_file(
+                remote_archive,
+                local_archive,
+                version,
+                verbose=verbose,
+            )
+            return audeer.extract_archive(
+                local_archive,
+                dst_root,
+                verbose=verbose,
+            )
 
     def _get_file(
             self,
             src_path: str,
             dst_path: str,
+            verbose: bool,
     ) -> str:  # pragma: no cover
         r"""Get file from backend."""
         raise NotImplementedError()
@@ -143,6 +152,7 @@ class Backend:
             version: str,
             *,
             ext: str = None,
+            verbose: bool = False,
     ):
         r"""Get file from backend.
 
@@ -151,6 +161,7 @@ class Backend:
             dst_path: destination path to local file
             version: version string
             ext: file extension, if ``None`` uses characters after last dot
+            verbose: show debug messages
 
         Returns:
             full path to local file
@@ -168,7 +179,7 @@ class Backend:
         dst_path = audeer.safe_path(dst_path)
         audeer.mkdir(os.path.dirname(dst_path))
 
-        self._get_file(src_path, dst_path)
+        self._get_file(src_path, dst_path, verbose)
 
     def _glob(
             self,
@@ -321,12 +332,7 @@ class Backend:
             'archive1-1.0.0.tar.gz'
 
         """
-        allowed_chars = re.compile(BACKEND_ALLOWED_CHARS)
-        if allowed_chars.fullmatch(path) is None:
-            raise ValueError(
-                f"Invalid path name '{path}', "
-                f"allowed characters are '{BACKEND_ALLOWED_CHARS}'."
-            )
+        utils.check_path_for_allowed_chars(path)
         folder, file = self.split(path)
         if ext is None:
             name, ext = os.path.splitext(file)
@@ -349,6 +355,8 @@ class Backend:
             files: typing.Union[str, typing.Sequence[str]],
             dst_path: str,
             version: str,
+            *,
+            verbose: bool = False,
     ) -> str:
         r"""Create archive and put on backend.
 
@@ -364,6 +372,7 @@ class Backend:
             dst_path: path to archive on backend without extension,
                 e.g. ``media/archive1``
             version: version string
+            verbose: show debug messages
 
         Returns:
             archive path on backend
@@ -372,6 +381,7 @@ class Backend:
             FileNotFoundError: if one or more files do not exist
 
         """
+        utils.check_path_for_allowed_chars(dst_path)
         src_root = audeer.safe_path(src_root)
 
         if isinstance(files, str):
@@ -387,14 +397,25 @@ class Backend:
         with tempfile.TemporaryDirectory() as tmp:
             _, archive_name = self.split(dst_path)
             archive = os.path.join(tmp, f'{archive_name}-{version}.zip')
-            audeer.create_archive(src_root, files, archive)
+            audeer.create_archive(
+                src_root,
+                files,
+                archive,
+                verbose=verbose,
+            )
             remote_archive = dst_path + '.zip'
-            return self.put_file(archive, remote_archive, version)
+            return self.put_file(
+                archive,
+                remote_archive,
+                version,
+                verbose=verbose,
+            )
 
     def _put_file(
             self,
             src_path: str,
             dst_path: str,
+            verbose: bool,
     ):  # pragma: no cover
         r"""Put file to backend."""
         raise NotImplementedError()
@@ -406,6 +427,7 @@ class Backend:
             version: str,
             *,
             ext: str = None,
+            verbose: bool = False,
     ):
         r"""Put file on backend.
 
@@ -418,6 +440,7 @@ class Backend:
             dst_path: path to file on backend
             version: version string
             ext: file extension, if ``None`` uses characters after last dot
+            verbose: show debug messages
 
         Returns:
             file path on backend
@@ -437,7 +460,7 @@ class Backend:
         skip = self._exists(dst_path) and \
             utils.md5(src_path) == self._checksum(dst_path)
         if not skip:
-            self._put_file(src_path, dst_path)
+            self._put_file(src_path, dst_path, verbose)
 
         return dst_path
 
